@@ -43,6 +43,8 @@
 #include "digesthmac.h"
 #include "qop.h"
 
+#include "mechtools.h"
+
 #define CNONCE_ENTROPY_BYTES 16
 
 struct _Gsasl_digest_md5_client_state
@@ -96,7 +98,7 @@ _gsasl_digest_md5_client_step (Gsasl_session * sctx,
 			       void *mech_data,
 			       const char *input,
 			       size_t input_len,
-			       char **output, size_t * output_len)
+			       char **output, size_t *output_len)
 {
   _Gsasl_digest_md5_client_state *state = mech_data;
   int rc, res;
@@ -211,12 +213,11 @@ _gsasl_digest_md5_client_step (Gsasl_session * sctx,
 	  if (rc < 0)
 	    return GSASL_MALLOC_ERROR;
 
-	  rc = gsasl_md5 (tmp, strlen (tmp), &tmp2);
+	  rc = _gsasl_hash (GSASL_HASH_MD5, tmp, strlen (tmp),
+			    state->secret);
 	  free (tmp);
 	  if (rc != GSASL_OK)
 	    return rc;
-	  memcpy (state->secret, tmp2, DIGEST_MD5_LENGTH);
-	  free (tmp2);
 	}
 
 	rc = digest_md5_hmac (state->response.response,
@@ -297,7 +298,7 @@ _gsasl_digest_md5_client_encode (Gsasl_session * sctx,
 				 void *mech_data,
 				 const char *input,
 				 size_t input_len,
-				 char **output, size_t * output_len)
+				 char **output, size_t *output_len)
 {
   _Gsasl_digest_md5_client_state *state = mech_data;
   int res;
@@ -321,7 +322,7 @@ _gsasl_digest_md5_client_decode (Gsasl_session * sctx,
 				 void *mech_data,
 				 const char *input,
 				 size_t input_len,
-				 char **output, size_t * output_len)
+				 char **output, size_t *output_len)
 {
   _Gsasl_digest_md5_client_state *state = mech_data;
   int res;
