@@ -44,6 +44,8 @@
 #include "validate.h"
 #include "qop.h"
 
+#include "mechtools.h"
+
 #define NONCE_ENTROPY_BYTES 16
 
 struct _Gsasl_digest_md5_server_state
@@ -144,7 +146,7 @@ _gsasl_digest_md5_server_step (Gsasl_session * sctx,
 			       void *mech_data,
 			       const char *input,
 			       size_t input_len,
-			       char **output, size_t * output_len)
+			       char **output, size_t *output_len)
 {
   _Gsasl_digest_md5_server_state *state = mech_data;
   int rc, res;
@@ -272,13 +274,11 @@ _gsasl_digest_md5_server_step (Gsasl_session * sctx,
 	    if (rc < 0)
 	      return GSASL_MALLOC_ERROR;
 
-	    rc = gsasl_md5 (tmp, strlen (tmp), &tmp2);
+	    rc = _gsasl_hash (GSASL_HASH_MD5, tmp, strlen (tmp),
+			      state->secret);
 	    free (tmp);
 	    if (rc != GSASL_OK)
 	      return rc;
-
-	    memcpy (state->secret, tmp2, DIGEST_MD5_LENGTH);
-	    free (tmp2);
 	  }
 	else
 	  {
@@ -352,7 +352,7 @@ _gsasl_digest_md5_server_encode (Gsasl_session * sctx,
 				 void *mech_data,
 				 const char *input,
 				 size_t input_len,
-				 char **output, size_t * output_len)
+				 char **output, size_t *output_len)
 {
   _Gsasl_digest_md5_server_state *state = mech_data;
   int res;
@@ -376,7 +376,7 @@ _gsasl_digest_md5_server_decode (Gsasl_session * sctx,
 				 void *mech_data,
 				 const char *input,
 				 size_t input_len,
-				 char **output, size_t * output_len)
+				 char **output, size_t *output_len)
 {
   _Gsasl_digest_md5_server_state *state = mech_data;
   int res;
