@@ -1,5 +1,5 @@
 /* test-parser.c --- Self tests of DIGEST-MD5 parser & printer.
- * Copyright (C) 2004-2012 Simon Josefsson
+ * Copyright (C) 2004-2020 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -20,6 +20,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
