@@ -1,5 +1,5 @@
 /* gc-pbkdf2-sha1.c --- Password-Based Key Derivation Function a'la PKCS#5
-   Copyright (C) 2002-2006, 2009-2019 Free Software Foundation, Inc.
+   Copyright (C) 2002-2006, 2009-2020 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
@@ -23,6 +23,10 @@
 #include <stdlib.h>
 #include <string.h>
 
+typedef Gc_rc (*gc_hmac_func) (const void *key, size_t keylen,
+			       const void *in, size_t inlen, char *resbuf);
+
+
 /* Implement PKCS#5 PBKDF2 as per RFC 2898.  The PRF to use is hard
    coded to be HMAC-SHA1.  Inputs are the password P of length PLEN,
    the salt S of length SLEN, the iteration counter C (> 0), and the
@@ -30,14 +34,15 @@
    must have room for at least DKLEN octets.  The output buffer will
    be filled with the derived data.  */
 Gc_rc
-gc_pbkdf2_sha1 (const char *P, size_t Plen,
-                const char *S, size_t Slen,
-                unsigned int c,
-                char *DK, size_t dkLen)
+gc_pbkdf2 (const char *P, size_t Plen,
+	   const char *S, size_t Slen,
+	   unsigned int c,
+	   char *DK, size_t dkLen,
+	   unsigned int hLen,
+	   gc_hmac_func f)
 {
-  unsigned int hLen = 20;
-  char U[20];
-  char T[20];
+  char U[32];
+  char T[32];
   unsigned int u;
   unsigned int l;
   unsigned int r;
@@ -78,10 +83,10 @@ gc_pbkdf2_sha1 (const char *P, size_t Plen,
               tmp[Slen + 2] = (i & 0x0000ff00) >> 8;
               tmp[Slen + 3] = (i & 0x000000ff) >> 0;
 
-              rc = gc_hmac_sha1 (P, Plen, tmp, tmplen, U);
+              rc = f (P, Plen, tmp, tmplen, U);
             }
           else
-            rc = gc_hmac_sha1 (P, Plen, U, hLen, U);
+            rc = f (P, Plen, U, hLen, U);
 
           if (rc != GC_OK)
             {
@@ -100,3 +105,21 @@ gc_pbkdf2_sha1 (const char *P, size_t Plen,
 
   return GC_OK;
 }
+
+Gc_rc
+gc_pbkdf2_sha1 (const char *P, size_t Plen,
+		const char *S, size_t Slen,
+		unsigned int c,
+		char *DK, size_t dkLen)
+{
+  return gc_pbkdf2 (P, Plen, S, Slen, c, DK, dkLen, 20, gc_hmac_sha1);
+}
+
+Gc_rc
+gc_pbkdf2_sha256 (const char *P, size_t Plen,
+		  const char *S, size_t Slen,
+		  unsigned int c,
+		  char *DK, size_t dkLen)
+{
+  return gc_pbkdf2 (P, Plen, S, Slen, c, DK, dkLen, 32, gc_hmac_sha256);
+}
