@@ -58,136 +58,136 @@ enum
   GSASL_UNICODE_NORMALIZATION_ERROR = 28,
   GSASL_NO_MORE_REALMS = 34,
   GSASL_INVALID_HANDLE = 50
-} __attribute__ ((deprecated));
+} __attribute__((deprecated));
 
-typedef Gsasl Gsasl_ctx __attribute__ ((deprecated));
-typedef Gsasl_session Gsasl_session_ctx __attribute__ ((deprecated));
+typedef Gsasl Gsasl_ctx __attribute__((deprecated));
+typedef Gsasl_session Gsasl_session_ctx __attribute__((deprecated));
 extern GSASL_API int gsasl_client_listmech (Gsasl * ctx, char *out,
-					    size_t * outlen)
-  __attribute__ ((deprecated));
+					    size_t *outlen)
+  __attribute__((deprecated));
 extern GSASL_API int gsasl_server_listmech (Gsasl * ctx, char *out,
-					    size_t * outlen)
-  __attribute__ ((deprecated));
+					    size_t *outlen)
+  __attribute__((deprecated));
 extern GSASL_API int gsasl_client_step (Gsasl_session * sctx,
 					const char *input, size_t input_len,
-					char *output, size_t * output_len)
-  __attribute__ ((deprecated));
+					char *output, size_t *output_len)
+  __attribute__((deprecated));
 extern GSASL_API int gsasl_client_step_base64 (Gsasl_session * sctx,
 					       const char *b64input,
 					       char *b64output,
 					       size_t b64output_len)
-  __attribute__ ((deprecated));
+  __attribute__((deprecated));
 extern GSASL_API int gsasl_server_step (Gsasl_session * sctx,
 					const char *input, size_t input_len,
-					char *output, size_t * output_len)
-  __attribute__ ((deprecated));
+					char *output, size_t *output_len)
+  __attribute__((deprecated));
 extern GSASL_API int gsasl_server_step_base64 (Gsasl_session * sctx,
 					       const char *b64input,
 					       char *b64output,
 					       size_t b64output_len)
-  __attribute__ ((deprecated));
+  __attribute__((deprecated));
 extern GSASL_API void gsasl_client_finish (Gsasl_session * sctx)
-  __attribute__ ((deprecated));
+  __attribute__((deprecated));
 extern GSASL_API void gsasl_server_finish (Gsasl_session * sctx)
-  __attribute__ ((deprecated));
+  __attribute__((deprecated));
 extern GSASL_API Gsasl *gsasl_client_ctx_get (Gsasl_session * sctx)
-  __attribute__ ((deprecated));
+  __attribute__((deprecated));
 extern GSASL_API Gsasl *gsasl_server_ctx_get (Gsasl_session * sctx)
-  __attribute__ ((deprecated));
+  __attribute__((deprecated));
 extern GSASL_API void gsasl_client_application_data_set (Gsasl_session * sctx,
 							 void
 							 *application_data)
-  __attribute__ ((deprecated));
+  __attribute__((deprecated));
 extern GSASL_API void *gsasl_client_application_data_get (Gsasl_session *
 							  sctx)
-  __attribute__ ((deprecated));
+  __attribute__((deprecated));
 extern GSASL_API void gsasl_server_application_data_set (Gsasl_session * sctx,
 							 void
 							 *application_data)
-  __attribute__ ((deprecated));
+  __attribute__((deprecated));
 extern GSASL_API void *gsasl_server_application_data_get (Gsasl_session *
 							  sctx)
-  __attribute__ ((deprecated));
+  __attribute__((deprecated));
 extern GSASL_API int gsasl_randomize (int strong, char *data, size_t datalen)
-  __attribute__ ((deprecated));
+  __attribute__((deprecated));
 extern GSASL_API Gsasl *gsasl_ctx_get (Gsasl_session * sctx)
-  __attribute__ ((deprecated));
+  __attribute__((deprecated));
 extern GSASL_API int gsasl_encode_inline (Gsasl_session * sctx,
 					  const char *input, size_t input_len,
-					  char *output, size_t * output_len)
-  __attribute__ ((deprecated));
+					  char *output, size_t *output_len)
+  __attribute__((deprecated));
 extern GSASL_API int gsasl_decode_inline (Gsasl_session * sctx,
 					  const char *input, size_t input_len,
-					  char *output, size_t * output_len)
-  __attribute__ ((deprecated));
+					  char *output, size_t *output_len)
+  __attribute__((deprecated));
 extern GSASL_API void gsasl_application_data_set (Gsasl * ctx, void *appdata)
-  __attribute__ ((deprecated));
+  __attribute__((deprecated));
 extern GSASL_API void *gsasl_application_data_get (Gsasl * ctx)
-  __attribute__ ((deprecated));
+  __attribute__((deprecated));
 extern GSASL_API void gsasl_appinfo_set (Gsasl_session * sctx, void *appdata)
-  __attribute__ ((deprecated));
+  __attribute__((deprecated));
 extern GSASL_API void *gsasl_appinfo_get (Gsasl_session * sctx)
-  __attribute__ ((deprecated));
+  __attribute__((deprecated));
 extern GSASL_API const char *gsasl_server_suggest_mechanism (Gsasl * ctx,
 							     const char
 							     *mechlist)
-  __attribute__ ((deprecated));
+  __attribute__((deprecated));
 
 extern GSASL_API int gsasl_base64_encode (char const *src, size_t srclength,
 					  char *target, size_t targsize)
-  __attribute__ ((deprecated));
+  __attribute__((deprecated));
 extern GSASL_API int gsasl_base64_decode (char const *src,
 					  char *target, size_t targsize)
-  __attribute__ ((deprecated));
+  __attribute__((deprecated));
 
 extern GSASL_API char *gsasl_stringprep_nfkc (const char *in, ssize_t len)
-  __attribute__ ((deprecated));
+  __attribute__((deprecated));
 extern GSASL_API char *gsasl_stringprep_saslprep (const char *in,
 						  int *stringprep_rc)
-  __attribute__ ((deprecated));
+  __attribute__((deprecated));
 extern GSASL_API char *gsasl_stringprep_trace (const char *in,
 					       int *stringprep_rc)
-  __attribute__ ((deprecated));
+  __attribute__((deprecated));
 
 extern GSASL_API int gsasl_md5pwd_get_password (const char *filename,
 						const char *username,
-						char *key, size_t * keylen)
-  __attribute__ ((deprecated));
+						char *key, size_t *keylen)
+  __attribute__((deprecated));
 
 /* Callback prototypes */
 typedef int (*Gsasl_client_callback_anonymous) (Gsasl_session * sctx,
-						char *out, size_t * outlen);
+						char *out, size_t *outlen);
 typedef int (*Gsasl_client_callback_authentication_id) (Gsasl_session * sctx,
 							char *out,
-							size_t * outlen);
+							size_t *outlen);
 typedef int (*Gsasl_client_callback_authorization_id) (Gsasl_session * sctx,
 						       char *out,
-						       size_t * outlen);
+						       size_t *outlen);
 typedef int (*Gsasl_client_callback_password) (Gsasl_session * sctx,
-					       char *out, size_t * outlen);
+					       char *out, size_t *outlen);
 typedef int (*Gsasl_client_callback_passcode) (Gsasl_session * sctx,
-					       char *out, size_t * outlen);
+					       char *out, size_t *outlen);
 typedef int (*Gsasl_client_callback_pin) (Gsasl_session * sctx,
 					  char *suggestion, char *out,
-					  size_t * outlen);
+					  size_t *outlen);
 typedef int (*Gsasl_client_callback_service) (Gsasl_session * sctx,
 					      char *service,
-					      size_t * servicelen,
+					      size_t *servicelen,
 					      char *hostname,
-					      size_t * hostnamelen,
+					      size_t *hostnamelen,
 					      char *servicename,
-					      size_t * servicenamelen);
+					      size_t *servicenamelen);
 typedef Gsasl_qop (*Gsasl_client_callback_qop) (Gsasl_session * sctx,
 						Gsasl_qop serverqops);
 typedef size_t (*Gsasl_client_callback_maxbuf) (Gsasl_session * sctx,
 						size_t servermaxbuf);
 typedef int (*Gsasl_client_callback_realm) (Gsasl_session * sctx, char *out,
-					    size_t * outlen);
+					    size_t *outlen);
 typedef int (*Gsasl_server_callback_retrieve) (Gsasl_session * sctx,
 					       const char *authentication_id,
 					       const char *authorization_id,
 					       const char *realm, char *key,
-					       size_t * keylen);
+					       size_t *keylen);
 typedef int (*Gsasl_server_callback_validate) (Gsasl_session * sctx,
 					       const char *authorization_id,
 					       const char *authentication_id,
@@ -200,7 +200,7 @@ typedef int (*Gsasl_server_callback_securid) (Gsasl_session * sctx,
 					      const char *authorization_id,
 					      const char *passcode, char *pin,
 					      char *suggestpin,
-					      size_t * suggestpinlen);
+					      size_t *suggestpinlen);
 typedef int (*Gsasl_server_callback_cram_md5) (Gsasl_session * sctx,
 					       char *username,
 					       char *challenge,
@@ -210,14 +210,14 @@ typedef int (*Gsasl_server_callback_digest_md5) (Gsasl_session * sctx,
 						 char *secrethash);
 typedef int (*Gsasl_server_callback_service) (Gsasl_session * sctx,
 					      char *service,
-					      size_t * servicelen,
+					      size_t *servicelen,
 					      char *hostname,
-					      size_t * hostnamelen);
+					      size_t *hostnamelen);
 typedef int (*Gsasl_server_callback_external) (Gsasl_session * sctx);
 typedef int (*Gsasl_server_callback_anonymous) (Gsasl_session * sctx,
 						const char *token);
 typedef int (*Gsasl_server_callback_realm) (Gsasl_session * sctx, char *out,
-					    size_t * outlen, size_t nth);
+					    size_t *outlen, size_t nth);
 typedef Gsasl_qop (*Gsasl_server_callback_qop) (Gsasl_session * sctx);
 typedef size_t (*Gsasl_server_callback_maxbuf) (Gsasl_session * sctx);
 typedef Gsasl_cipher (*Gsasl_server_callback_cipher) (Gsasl_session * sctx);
@@ -226,163 +226,176 @@ typedef Gsasl_cipher (*Gsasl_server_callback_cipher) (Gsasl_session * sctx);
 extern GSASL_API void
   gsasl_client_callback_authorization_id_set
   (Gsasl * ctx, Gsasl_client_callback_authorization_id cb)
-  __attribute__ ((deprecated));
+  __attribute__((deprecated));
 extern GSASL_API Gsasl_client_callback_authorization_id
 gsasl_client_callback_authorization_id_get (Gsasl * ctx)
-__attribute__ ((deprecated));
+__attribute__((deprecated));
 
 extern GSASL_API void
   gsasl_client_callback_authentication_id_set
   (Gsasl * ctx, Gsasl_client_callback_authentication_id cb)
-  __attribute__ ((deprecated));
+  __attribute__((deprecated));
 extern GSASL_API Gsasl_client_callback_authentication_id
 gsasl_client_callback_authentication_id_get (Gsasl * ctx)
-__attribute__ ((deprecated));
+__attribute__((deprecated));
 
 extern GSASL_API void
 gsasl_client_callback_anonymous_set (Gsasl * ctx,
 				     Gsasl_client_callback_anonymous cb)
-__attribute__ ((deprecated));
+__attribute__((deprecated));
 extern GSASL_API Gsasl_client_callback_anonymous
-gsasl_client_callback_anonymous_get (Gsasl * ctx)
-__attribute__ ((deprecated));
+gsasl_client_callback_anonymous_get (Gsasl * ctx) __attribute__((deprecated));
 
 extern GSASL_API void
 gsasl_client_callback_password_set (Gsasl * ctx,
 				    Gsasl_client_callback_password cb)
-__attribute__ ((deprecated));
+__attribute__((deprecated));
 extern GSASL_API Gsasl_client_callback_password
-gsasl_client_callback_password_get (Gsasl * ctx) __attribute__ ((deprecated));
+gsasl_client_callback_password_get (Gsasl * ctx) __attribute__((deprecated));
 
 extern GSASL_API void
 gsasl_client_callback_passcode_set (Gsasl * ctx,
 				    Gsasl_client_callback_passcode cb)
-__attribute__ ((deprecated));
+__attribute__((deprecated));
 extern GSASL_API Gsasl_client_callback_passcode
-gsasl_client_callback_passcode_get (Gsasl * ctx) __attribute__ ((deprecated));
+gsasl_client_callback_passcode_get (Gsasl * ctx) __attribute__((deprecated));
 
 extern GSASL_API void
 gsasl_client_callback_pin_set (Gsasl * ctx, Gsasl_client_callback_pin cb)
-__attribute__ ((deprecated));
+__attribute__((deprecated));
 extern GSASL_API Gsasl_client_callback_pin
-gsasl_client_callback_pin_get (Gsasl * ctx) __attribute__ ((deprecated));
+gsasl_client_callback_pin_get (Gsasl * ctx) __attribute__((deprecated));
 
 extern GSASL_API void
 gsasl_client_callback_service_set (Gsasl * ctx,
 				   Gsasl_client_callback_service cb)
-__attribute__ ((deprecated));
+__attribute__((deprecated));
 extern GSASL_API Gsasl_client_callback_service
-gsasl_client_callback_service_get (Gsasl * ctx) __attribute__ ((deprecated));
+gsasl_client_callback_service_get (Gsasl * ctx) __attribute__((deprecated));
 
 extern GSASL_API void
 gsasl_client_callback_qop_set (Gsasl * ctx, Gsasl_client_callback_qop cb)
-__attribute__ ((deprecated));
+__attribute__((deprecated));
 extern GSASL_API Gsasl_client_callback_qop
-gsasl_client_callback_qop_get (Gsasl * ctx) __attribute__ ((deprecated));
+gsasl_client_callback_qop_get (Gsasl * ctx) __attribute__((deprecated));
 
 extern GSASL_API void
 gsasl_client_callback_maxbuf_set (Gsasl * ctx,
 				  Gsasl_client_callback_maxbuf cb)
-__attribute__ ((deprecated));
+__attribute__((deprecated));
 extern GSASL_API Gsasl_client_callback_maxbuf
-gsasl_client_callback_maxbuf_get (Gsasl * ctx) __attribute__ ((deprecated));
+gsasl_client_callback_maxbuf_get (Gsasl * ctx) __attribute__((deprecated));
 extern GSASL_API
   void gsasl_client_callback_realm_set (Gsasl * ctx,
 					Gsasl_client_callback_realm cb)
-  __attribute__ ((deprecated));
+  __attribute__((deprecated));
 extern GSASL_API Gsasl_client_callback_realm
-gsasl_client_callback_realm_get (Gsasl * ctx) __attribute__ ((deprecated));
+gsasl_client_callback_realm_get (Gsasl * ctx) __attribute__((deprecated));
 
 /* Obsolete server callbacks: callback-s.c */
 extern GSASL_API void
 gsasl_server_callback_validate_set (Gsasl * ctx,
 				    Gsasl_server_callback_validate cb)
-__attribute__ ((deprecated));
+__attribute__((deprecated));
 extern GSASL_API Gsasl_server_callback_validate
-gsasl_server_callback_validate_get (Gsasl * ctx) __attribute__ ((deprecated));
+gsasl_server_callback_validate_get (Gsasl * ctx) __attribute__((deprecated));
 
 extern GSASL_API void
 gsasl_server_callback_retrieve_set (Gsasl * ctx,
 				    Gsasl_server_callback_retrieve cb)
-__attribute__ ((deprecated));
+__attribute__((deprecated));
 extern GSASL_API Gsasl_server_callback_retrieve
-gsasl_server_callback_retrieve_get (Gsasl * ctx) __attribute__ ((deprecated));
+gsasl_server_callback_retrieve_get (Gsasl * ctx) __attribute__((deprecated));
 
 extern GSASL_API void
 gsasl_server_callback_cram_md5_set (Gsasl * ctx,
 				    Gsasl_server_callback_cram_md5 cb)
-__attribute__ ((deprecated));
+__attribute__((deprecated));
 extern GSASL_API Gsasl_server_callback_cram_md5
-gsasl_server_callback_cram_md5_get (Gsasl * ctx) __attribute__ ((deprecated));
+gsasl_server_callback_cram_md5_get (Gsasl * ctx) __attribute__((deprecated));
 
 extern GSASL_API void
 gsasl_server_callback_digest_md5_set (Gsasl * ctx,
 				      Gsasl_server_callback_digest_md5 cb)
-__attribute__ ((deprecated));
+__attribute__((deprecated));
 extern GSASL_API Gsasl_server_callback_digest_md5
 gsasl_server_callback_digest_md5_get (Gsasl * ctx)
-__attribute__ ((deprecated));
+__attribute__((deprecated));
 
 extern GSASL_API void
 gsasl_server_callback_external_set (Gsasl * ctx,
 				    Gsasl_server_callback_external cb)
-__attribute__ ((deprecated));
+__attribute__((deprecated));
 extern GSASL_API Gsasl_server_callback_external
-gsasl_server_callback_external_get (Gsasl * ctx) __attribute__ ((deprecated));
+gsasl_server_callback_external_get (Gsasl * ctx) __attribute__((deprecated));
 
 extern GSASL_API void
 gsasl_server_callback_anonymous_set (Gsasl * ctx,
 				     Gsasl_server_callback_anonymous cb)
-__attribute__ ((deprecated));
+__attribute__((deprecated));
 extern GSASL_API Gsasl_server_callback_anonymous
-gsasl_server_callback_anonymous_get (Gsasl * ctx)
-__attribute__ ((deprecated));
+gsasl_server_callback_anonymous_get (Gsasl * ctx) __attribute__((deprecated));
 
 extern GSASL_API void
 gsasl_server_callback_realm_set (Gsasl * ctx, Gsasl_server_callback_realm cb)
-__attribute__ ((deprecated));
+__attribute__((deprecated));
 extern GSASL_API Gsasl_server_callback_realm
-gsasl_server_callback_realm_get (Gsasl * ctx) __attribute__ ((deprecated));
+gsasl_server_callback_realm_get (Gsasl * ctx) __attribute__((deprecated));
 
 extern GSASL_API void
 gsasl_server_callback_qop_set (Gsasl * ctx, Gsasl_server_callback_qop cb)
-__attribute__ ((deprecated));
+__attribute__((deprecated));
 extern GSASL_API Gsasl_server_callback_qop
-gsasl_server_callback_qop_get (Gsasl * ctx) __attribute__ ((deprecated));
+gsasl_server_callback_qop_get (Gsasl * ctx) __attribute__((deprecated));
 
 extern GSASL_API void
 gsasl_server_callback_maxbuf_set (Gsasl * ctx,
 				  Gsasl_server_callback_maxbuf cb)
-__attribute__ ((deprecated));
+__attribute__((deprecated));
 extern GSASL_API Gsasl_server_callback_maxbuf
-gsasl_server_callback_maxbuf_get (Gsasl * ctx) __attribute__ ((deprecated));
+gsasl_server_callback_maxbuf_get (Gsasl * ctx) __attribute__((deprecated));
 
 extern GSASL_API void
 gsasl_server_callback_cipher_set (Gsasl * ctx,
 				  Gsasl_server_callback_cipher cb)
-__attribute__ ((deprecated));
+__attribute__((deprecated));
 extern GSASL_API Gsasl_server_callback_cipher
-gsasl_server_callback_cipher_get (Gsasl * ctx) __attribute__ ((deprecated));
+gsasl_server_callback_cipher_get (Gsasl * ctx) __attribute__((deprecated));
 
 extern GSASL_API void
 gsasl_server_callback_securid_set (Gsasl * ctx,
 				   Gsasl_server_callback_securid cb)
-__attribute__ ((deprecated));
+__attribute__((deprecated));
 extern GSASL_API Gsasl_server_callback_securid
-gsasl_server_callback_securid_get (Gsasl * ctx) __attribute__ ((deprecated));
+gsasl_server_callback_securid_get (Gsasl * ctx) __attribute__((deprecated));
 
 extern GSASL_API void
 gsasl_server_callback_gssapi_set (Gsasl * ctx,
 				  Gsasl_server_callback_gssapi cb)
-__attribute__ ((deprecated));
+__attribute__((deprecated));
 extern GSASL_API Gsasl_server_callback_gssapi
-gsasl_server_callback_gssapi_get (Gsasl * ctx) __attribute__ ((deprecated));
+gsasl_server_callback_gssapi_get (Gsasl * ctx) __attribute__((deprecated));
 
 extern GSASL_API void
 gsasl_server_callback_service_set (Gsasl * ctx,
 				   Gsasl_server_callback_service cb)
-__attribute__ ((deprecated));
+__attribute__((deprecated));
 extern GSASL_API Gsasl_server_callback_service
-gsasl_server_callback_service_get (Gsasl * ctx) __attribute__ ((deprecated));
+gsasl_server_callback_service_get (Gsasl * ctx) __attribute__((deprecated));
+
+extern GSASL_API int
+gsasl_md5 (const char *in, size_t inlen,
+	   char *out[]) __attribute__((deprecated));
+extern GSASL_API int
+gsasl_hmac_md5 (const char *key, size_t keylen,
+		const char *in, size_t inlen,
+		char *outhash[]) __attribute__((deprecated));
+extern GSASL_API int
+gsasl_sha1 (const char *in, size_t inlen,
+	    char *out[]) __attribute__((deprecated));
+extern GSASL_API int
+gsasl_hmac_sha1 (const char *key, size_t keylen,
+		 const char *in, size_t inlen,
+		 char *outhash[]) __attribute__((deprecated));
 
 #endif /* GSASL_COMPAT_H */
