@@ -43,7 +43,7 @@
  * Deprecated: Use gsasl_client_mechlist() instead.
  **/
 int
-gsasl_client_listmech (Gsasl * ctx, char *out, size_t * outlen)
+gsasl_client_listmech (Gsasl * ctx, char *out, size_t *outlen)
 {
   char *tmp;
   int rc;
@@ -86,7 +86,7 @@ gsasl_client_listmech (Gsasl * ctx, char *out, size_t * outlen)
  * Deprecated: Use gsasl_server_mechlist() instead.
  **/
 int
-gsasl_server_listmech (Gsasl * ctx, char *out, size_t * outlen)
+gsasl_server_listmech (Gsasl * ctx, char *out, size_t *outlen)
 {
   char *tmp;
   int rc;
@@ -115,7 +115,7 @@ gsasl_server_listmech (Gsasl * ctx, char *out, size_t * outlen)
 static int
 _gsasl_step (Gsasl_session * sctx,
 	     const char *input, size_t input_len,
-	     char *output, size_t * output_len)
+	     char *output, size_t *output_len)
 {
   char *tmp;
   size_t tmplen;
@@ -166,7 +166,7 @@ _gsasl_step (Gsasl_session * sctx,
 int
 gsasl_client_step (Gsasl_session * sctx,
 		   const char *input,
-		   size_t input_len, char *output, size_t * output_len)
+		   size_t input_len, char *output, size_t *output_len)
 {
   return _gsasl_step (sctx, input, input_len, output, output_len);
 }
@@ -196,7 +196,7 @@ gsasl_client_step (Gsasl_session * sctx,
 int
 gsasl_server_step (Gsasl_session * sctx,
 		   const char *input,
-		   size_t input_len, char *output, size_t * output_len)
+		   size_t input_len, char *output, size_t *output_len)
 {
   return _gsasl_step (sctx, input, input_len, output, output_len);
 }
@@ -473,7 +473,7 @@ gsasl_ctx_get (Gsasl_session * sctx)
 int
 gsasl_encode_inline (Gsasl_session * sctx,
 		     const char *input, size_t input_len,
-		     char *output, size_t * output_len)
+		     char *output, size_t *output_len)
 {
   char *tmp;
   size_t tmplen;
@@ -513,7 +513,7 @@ gsasl_encode_inline (Gsasl_session * sctx,
 int
 gsasl_decode_inline (Gsasl_session * sctx,
 		     const char *input, size_t input_len,
-		     char *output, size_t * output_len)
+		     char *output, size_t *output_len)
 {
   char *tmp;
   size_t tmplen;
@@ -1767,7 +1767,7 @@ gsasl_stringprep_trace (const char *in, int *stringprep_rc)
  **/
 int
 gsasl_md5pwd_get_password (const char *filename,
-			   const char *username, char *key, size_t * keylen)
+			   const char *username, char *key, size_t *keylen)
 {
   char *tmp;
   size_t tmplen;
@@ -2174,3 +2174,103 @@ _gsasl_obsolete_callback (Gsasl * ctx, Gsasl_session * sctx,
 
   return GSASL_NO_CALLBACK;
 }
+
+#include "gc.h"
+
+/**
+ * gsasl_md5:
+ * @in: input character array of data to hash.
+ * @inlen: length of input character array of data to hash.
+ * @out: newly allocated 16-byte character array with hash of data.
+ *
+ * Compute hash of data using MD5.  The @out buffer must be
+ * deallocated by the caller.
+ *
+ * Return value: Returns %GSASL_OK iff successful.
+ *
+ * Deprecated: Use a crypto library.
+ **/
+int
+gsasl_md5 (const char *in, size_t inlen, char *out[])
+{
+  *out = malloc (GC_MD5_DIGEST_SIZE);
+  if (!*out)
+    return GSASL_MALLOC_ERROR;
+  return gc_md5 (in, inlen, *out);
+}
+
+/**
+ * gsasl_hmac_md5:
+ * @key: input character array with key to use.
+ * @keylen: length of input character array with key to use.
+ * @in: input character array of data to hash.
+ * @inlen: length of input character array of data to hash.
+ * @outhash: newly allocated 16-byte character array with keyed hash of data.
+ *
+ * Compute keyed checksum of data using HMAC-MD5.  The @outhash buffer
+ * must be deallocated by the caller.
+ *
+ * Return value: Returns %GSASL_OK iff successful.
+ *
+ * Deprecated: Use a crypto library.
+ **/
+int
+gsasl_hmac_md5 (const char *key, size_t keylen,
+		const char *in, size_t inlen, char *outhash[])
+{
+  *outhash = malloc (GC_MD5_DIGEST_SIZE);
+  if (!*outhash)
+    return GSASL_MALLOC_ERROR;
+  return gc_hmac_md5 (key, keylen, in, inlen, *outhash);
+}
+
+/**
+ * gsasl_sha1:
+ * @in: input character array of data to hash.
+ * @inlen: length of input character array of data to hash.
+ * @out: newly allocated 20-byte character array with hash of data.
+ *
+ * Compute hash of data using SHA1.  The @out buffer must be
+ * deallocated by the caller.
+ *
+ * Return value: Returns %GSASL_OK iff successful.
+ *
+ * Since: 1.3
+ *
+ * Deprecated: Use a crypto library.
+ **/
+int
+gsasl_sha1 (const char *in, size_t inlen, char *out[])
+{
+  *out = malloc (GC_SHA1_DIGEST_SIZE);
+  if (!*out)
+    return GSASL_MALLOC_ERROR;
+  return gc_sha1 (in, inlen, *out);
+}
+
+/**
+ * gsasl_hmac_sha1:
+ * @key: input character array with key to use.
+ * @keylen: length of input character array with key to use.
+ * @in: input character array of data to hash.
+ * @inlen: length of input character array of data to hash.
+ * @outhash: newly allocated 20-byte character array with keyed hash of data.
+ *
+ * Compute keyed checksum of data using HMAC-SHA1.  The @outhash buffer
+ * must be deallocated by the caller.
+ *
+ * Return value: Returns %GSASL_OK iff successful.
+ *
+ * Since: 1.3
+ *
+ * Deprecated: Use a crypto library.
+ **/
+int
+gsasl_hmac_sha1 (const char *key, size_t keylen,
+		 const char *in, size_t inlen, char *outhash[])
+{
+  *outhash = malloc (GC_SHA1_DIGEST_SIZE);
+  if (!*outhash)
+    return GSASL_MALLOC_ERROR;
+  return gc_hmac_sha1 (key, keylen, in, inlen, *outhash);
+}
