@@ -57,7 +57,7 @@ readutf8line (const char *prompt)
   return locale_to_utf8 (p);
 }
 
-static char *
+char *
 readutf8pass (const char *prompt)
 {
   char *p = getpass (prompt);
@@ -201,8 +201,17 @@ callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
       break;
 
     case GSASL_SCRAM_SALTED_PASSWORD:
+      break;
+
     case GSASL_SCRAM_ITER:
+      gsasl_property_set (sctx, GSASL_SCRAM_ITER,
+			  args_info.iteration_count_orig);
+      rc = GSASL_OK;
+      break;
+
     case GSASL_SCRAM_SALT:
+      gsasl_property_set (sctx, GSASL_SCRAM_SALT, args_info.salt_arg);
+      rc = GSASL_OK;
       break;
 
     case GSASL_SAML20_IDP_IDENTIFIER:
@@ -218,7 +227,8 @@ callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
 
     case GSASL_SAML20_AUTHENTICATE_IN_BROWSER:
       {
-	const char *url = gsasl_property_get (sctx, GSASL_SAML20_REDIRECT_URL);
+	const char *url =
+	  gsasl_property_get (sctx, GSASL_SAML20_REDIRECT_URL);
 
 	printf ("Proceed to this URL to authenticate using SAML 2.0:\n%s\n",
 		url);
