@@ -279,6 +279,109 @@ usage (int status)
   exit (status);
 }
 
+#define DEFAULT_SALT_SIZE 12
+
+static void
+mkpasswd (void)
+{
+  char salt_buf[DEFAULT_SALT_SIZE];
+  char *salt;
+  size_t saltlen;
+  char *b64salt;
+  char saltedpassword[GSASL_HASH_MAX_SIZE];
+  char *hexsaltedpassword;
+  size_t hexsaltedpasswordlen;
+  int hash = 0;
+  size_t hashlen = 0;
+  char clientkey[GSASL_HASH_MAX_SIZE];
+  char serverkey[GSASL_HASH_MAX_SIZE];
+  char storedkey[GSASL_HASH_MAX_SIZE];
+  char *b64serverkey, *b64storedkey;
+  size_t b64serverkeylen, b64storedkeylen;
+  int res;
+
+  if (args_info.mechanism_arg == NULL)
+    error (EXIT_FAILURE, 0, _("required --mechanism missing"));
+
+  if (strcmp (args_info.mechanism_arg, "SCRAM-SHA-1") == 0)
+    {
+      hash = GSASL_HASH_SHA1;
+      hashlen = GSASL_HASH_SHA1_SIZE;
+    }
+  else if (strcmp (args_info.mechanism_arg, "SCRAM-SHA-256") == 0)
+    {
+      hash = GSASL_HASH_SHA256;
+      hashlen = GSASL_HASH_SHA256_SIZE;
+    }
+  else
+    error (EXIT_FAILURE, 0, _("unsupported --mechanism for --mkpasswd: %s"),
+	   args_info.mechanism_arg);
+
+  if (args_info.iteration_count_arg <= 0)
+    error (EXIT_FAILURE, 0, _("iteration count must be positive: %d"),
+	   args_info.iteration_count_arg);
+
+  if (args_info.salt_given)
+    {
+      b64salt = args_info.salt_arg;
+
+      res = gsasl_base64_from (b64salt, strlen (b64salt), &salt, &saltlen);
+      if (res != GSASL_OK)
+	error (EXIT_FAILURE, 0, "%s: %s", gsasl_strerror (res), b64salt);
+    }
+  else
+    {
+      salt = salt_buf;
+      saltlen = sizeof (salt_buf);
+
+      res = gsasl_nonce (salt, saltlen);
+      if (res != GSASL_OK)
+	error (EXIT_FAILURE, 0, "%s", gsasl_strerror (res));
+
+      res = gsasl_base64_to (salt, saltlen, &b64salt, NULL);
+      if (res != GSASL_OK)
+	error (EXIT_FAILURE, 0, "%s", gsasl_strerror (res));
+    }
+
+  if (args_info.password_arg == NULL)
+    args_info.password_arg = readutf8pass (_("Enter password: "));
+
+  res = gsasl_scram_secrets_from_password (hash, args_info.password_arg,
+					   args_info.iteration_count_arg,
+					   salt, saltlen,
+					   saltedpassword,
+					   clientkey, serverkey, storedkey);
+  if (res != GSASL_OK)
+    error (EXIT_FAILURE, 0, "%s", gsasl_strerror (res));
+
+  res = gsasl_hex_to (saltedpassword, hashlen,
+		      &hexsaltedpassword, &hexsaltedpasswordlen);
+  if (res != GSASL_OK)
+    error (EXIT_FAILURE, 0, "%s", gsasl_strerror (res));
+
+  res = gsasl_base64_to (storedkey, hashlen, &b64storedkey, &b64storedkeylen);
+  if (res != GSASL_OK)
+    error (EXIT_FAILURE, 0, "%s", gsasl_strerror (res));
+
+  res = gsasl_base64_to (serverkey, hashlen, &b64serverkey, &b64serverkeylen);
+  if (res != GSASL_OK)
+    error (EXIT_FAILURE, 0, "%s", gsasl_strerror (res));
+
+  printf ("%s:%d:%s:%s:%s:%s\n", args_info.mechanism_arg,
+	  args_info.iteration_count_arg,
+	  b64salt, hexsaltedpassword, b64serverkey, b64storedkey);
+
+  if (salt != salt_buf)
+    free (salt);
+  if (b64salt != args_info.salt_arg)
+    free (b64salt);
+  free (b64serverkey);
+  free (b64storedkey);
+  free (hexsaltedpassword);
+  free (b64salt);
+}
+
+
 int
 main (int argc, char *argv[])
 {
@@ -322,7 +425,8 @@ main (int argc, char *argv[])
 
   if (!(args_info.client_flag || args_info.client_given) &&
       !args_info.server_given &&
-      !args_info.client_mechanisms_flag && !args_info.server_mechanisms_flag)
+      !args_info.client_mechanisms_flag && !args_info.server_mechanisms_flag
+      && !args_info.mkpasswd_given)
     {
       error (0, 0, _("missing argument"));
       usage (EXIT_FAILURE);
@@ -342,7 +446,8 @@ main (int argc, char *argv[])
 
   if (!args_info.connect_given && args_info.inputs_num == 0 &&
       !args_info.client_given && !args_info.server_given &&
-      !args_info.client_mechanisms_flag && !args_info.server_mechanisms_flag)
+      !args_info.client_mechanisms_flag && !args_info.server_mechanisms_flag
+      && !args_info.mkpasswd_given)
     {
       cmdline_parser_print_help ();
       emit_bug_reporting_address ();
@@ -442,7 +547,13 @@ main (int argc, char *argv[])
 
       free (mechs);
 
-      return EXIT_SUCCESS;
+      goto done;
+    }
+
+  if (args_info.mkpasswd_given)
+    {
+      mkpasswd ();
+      goto done;
     }
 
   if (args_info.connect_given || args_info.inputs_num > 0)
@@ -637,7 +748,7 @@ main (int argc, char *argv[])
       if (mech == NULL)
 	{
 	  fprintf (stderr, _("Cannot find mechanism...\n"));
-	  return 0;
+	  goto done;
 	}
 
       if (args_info.mechanism_arg)
@@ -907,6 +1018,7 @@ main (int argc, char *argv[])
       close (sockfd);
     }
 
+done:
   gsasl_done (ctx);
 
 #ifdef HAVE_LIBGNUTLS
@@ -919,5 +1031,5 @@ main (int argc, char *argv[])
     }
 #endif
 
-  return 0;
+  return EXIT_SUCCESS;
 }
