@@ -93,13 +93,13 @@ callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
 	}
       break;
 
+#define SP1 "06bfd2d70a0fa425c20473722a93700df39f3cbd"
+#define SP2 "f1e6c0e5a207367176ac42c7799b67ae3e097d7e"
+
     case GSASL_SCRAM_SALTED_PASSWORD:
       if (i & 0x04 && i & 0x08)	/* Only works with fixed salt. */
 	{
-	  const char *str[] = {
-	    "06bfd2d70a0fa425c20473722a93700df39f3cbd",
-	    "f1e6c0e5a207367176ac42c7799b67ae3e097d7e",
-	  };
+	  const char *str[] = { SP1, SP2 };
 	  /* >>1 to mask out authzid. */
 	  size_t pos = (i & ~0x04 & ~0x08) >> 1;
 	  gsasl_property_set (sctx, prop, str[pos]);
@@ -107,6 +107,10 @@ callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
 	}
       break;
 
+    case GSASL_SCRAM_SERVERKEY:
+    case GSASL_SCRAM_STOREDKEY:
+      break;
+
     case GSASL_CB_TLS_UNIQUE:
       break;
 
@@ -361,6 +365,70 @@ doit (void)
 	  fail ("Expected authzid? %d/%s\n", i, AUTHZID[i % N_AUTHZID]);
       }
 
+      {
+	const char *ci = gsasl_property_fast (client, GSASL_SCRAM_ITER);
+	const char *si = gsasl_property_fast (server, GSASL_SCRAM_ITER);
+	if (debug)
+	  {
+	    printf ("GSASL_SCRAM_ITER (client): %s\n", ci);
+	    printf ("GSASL_SCRAM_ITER (server): %s\n", si);
+	  }
+	if (!ci || !si || strcmp (ci, si) != 0)
+	  fail ("scram iter mismatch\n");
+      }
+
+      {
+	const char *cs = gsasl_property_fast (client, GSASL_SCRAM_SALT);
+	const char *ss = gsasl_property_fast (server, GSASL_SCRAM_SALT);
+	if (debug)
+	  {
+	    printf ("GSASL_SCRAM_ITER (client): %s\n", cs);
+	    printf ("GSASL_SCRAM_ITER (server): %s\n", ss);
+	  }
+	if (!cs || !ss || strcmp (cs, ss) != 0)
+	  fail ("scram salt mismatch\n");
+      }
+
+      {
+	const char *csp =
+	  gsasl_property_fast (client, GSASL_SCRAM_SALTED_PASSWORD);
+	const char *ssp =
+	  gsasl_property_fast (server, GSASL_SCRAM_SALTED_PASSWORD);
+
+	if (debug)
+	  {
+	    printf ("GSASL_SCRAM_SALTED_PASSWORD (client): %s\n", csp);
+	    printf ("GSASL_SCRAM_SALTED_PASSWORD (server): %s\n", ssp);
+	  }
+	if (!csp || !ssp || strcmp (csp, ssp) != 0)
+	  fail ("scram salted password mismatch\n");
+      }
+
+
+      {
+	const char *sek = gsasl_property_fast (server, GSASL_SCRAM_SERVERKEY);
+	const char *stk = gsasl_property_fast (server, GSASL_SCRAM_STOREDKEY);
+	const char *ssp =
+	  gsasl_property_fast (server, GSASL_SCRAM_SALTED_PASSWORD);
+
+	if (debug)
+	  {
+	    printf ("GSASL_SCRAM_SERVERKEY: %s\n", sek);
+	    printf ("GSASL_SCRAM_STOREDKEY: %s\n", stk);
+	  }
+
+	if (!sek)
+	  fail ("missing ServerKey\n");
+	if (!stk)
+	  fail ("missing StoredKey\n");
+	if ((strcmp (ssp, SP2) == 0)
+	    && (strcmp (sek, "m05YwQmkiYtfagsfqHyTaFbylTI=") != 0))
+	  fail ("incorrect ServerKey\n");
+	if ((strcmp (ssp, SP2) == 0)
+	    && (strcmp (stk, "bgzByAo2e3aFvfezFeqJy5OJSUs=") != 0))
+	  fail ("incorrect StoredKey\n");
+      }
+
     done:
       if (debug)
 	printf ("\n");
