@@ -19,7 +19,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-# include "config.h"
+#include "config.h"
 #endif
 
 #include <gsasl.h>
@@ -54,9 +54,7 @@ doit (void)
   assert_symbol_exists ((const void *) gsasl_encode);
   assert_symbol_exists ((const void *) gsasl_finish);
   assert_symbol_exists ((const void *) gsasl_free);
-  assert_symbol_exists ((const void *) gsasl_hmac_md5);
   assert_symbol_exists ((const void *) gsasl_init);
-  assert_symbol_exists ((const void *) gsasl_md5);
   assert_symbol_exists ((const void *) gsasl_mechanism_name);
   assert_symbol_exists ((const void *) gsasl_nonce);
   assert_symbol_exists ((const void *) gsasl_property_fast);
@@ -77,6 +75,13 @@ doit (void)
   assert_symbol_exists ((const void *) gsasl_strerror);
   assert_symbol_exists ((const void *) gsasl_strerror_name);
 
+  /* LIBGSASL_1.10 */
+  assert_symbol_exists ((const void *) gsasl_hex_from);
+  assert_symbol_exists ((const void *) gsasl_hex_to);
+  assert_symbol_exists ((const void *) gsasl_hash_length);
+  assert_symbol_exists ((const void *) gsasl_scram_secrets_from_password);
+  assert_symbol_exists ((const void *) gsasl_scram_secrets_from_salted_password);
+
 #ifndef GSASL_NO_OBSOLETE
   /* LIBGSASL_1.1: Old interfaces */
   assert_symbol_exists ((const void *) gsasl_appinfo_get);
@@ -160,9 +165,14 @@ doit (void)
   assert_symbol_exists ((const void *) gsasl_stringprep_trace);
 #endif
 
+#ifndef GSASL_NO_OBSOLETE
+  /* Obsoleted in 1.10 */
+  assert_symbol_exists ((const void *) gsasl_hmac_md5);
+  assert_symbol_exists ((const void *) gsasl_md5);
   /* LIBGSASL_1.4 */
   assert_symbol_exists ((const void *) gsasl_sha1);
   assert_symbol_exists ((const void *) gsasl_hmac_sha1);
+#endif
 
   success ("all symbols exists\n");
 }
